@@ -1,5 +1,5 @@
 /* vokoscreenNG - A desktop recorder
- * Copyright (C) 2017-2019 Volker Kohaupt
+ * Copyright (C) 2017-2022 Volker Kohaupt
  * 
  * Author:
  *      Volker Kohaupt <vkohaupt@volkoh.de>
@@ -68,6 +68,11 @@ public slots:
     void slot_checkbox_shortcut_halo_currentIndexChanged( int value );
     void slot_toolButton_shortcut_halo_reset();
 
+    void slot_checkbox_shortcut_snapshot_clicked( bool value );
+    void slot_checkbox_shortcut_snapshot_currentIndexChanged( int value );
+    void slot_toolButton_shortcut_snapshot_reset();
+
+
 private:
     Ui_formMainWindow *ui;
     bool isBusy(QString check);
@@ -79,10 +84,12 @@ private:
     QGlobalShortcut *shortcutCamera;
     QGlobalShortcut *shortcutShowclick;
     QGlobalShortcut *shortcutHalo;
+    QGlobalShortcut *shortcutSnapshot;
 
     QvkSpezialCheckbox *spezialCheckboxShowclick;
     QvkSpezialCheckbox *spezialCheckboxHalo;
 
+
 private slots:
     void slot_pauseContinue();
     void slot_setOrUnsetShortcut( bool value );
