@@ -66,15 +66,11 @@ private:
     QString vk_helpPath;
 
     QTemporaryDir temporaryDirLocal;
-    QNetworkAccessManager networkAccessManager;
 
 
 private slots:
     void slot_parseHTML( QString tempPathFileName );
     void slot_showHelp( QString tempPathFileName );
-
-    void slot_NetworkAccessibility( QNetworkAccessManager::NetworkAccessibility accessible );
-
     void slot_parse_locale( QStringList list );
 
 
