@@ -13,6 +13,41 @@
         <translation>الكاميرا</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>إزالة إطار النافذة</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>تغيير الوجه الرأسي</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>تغيير الوجه الأفقي</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>عكس</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>رمادي</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>ابيض واسود</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation> أظهر النافذة</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>تغيير لملء الشاشة</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>تغيير لملء الشاشة</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>الكاميرا</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -103,6 +142,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>لايمكن ايجاد اداراه الملفات </translation>
     </message>
     <message>
@@ -147,6 +187,17 @@
         <translation>منطقة</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>لايمكن ايجاد اداراه الملفات </translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>الرجاء تنصيب اداره الملفات</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -209,6 +260,13 @@
         <translation>المكبّرة</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>اِختر جهازاً أو أكثر</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -406,10 +464,6 @@
         <source>Gray</source>
         <translation>رمادي</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>ارسل التقرير</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -522,6 +576,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>إذا ظهر أنه تم تعيينه ولكنه لا يعمل ، فهذا يعني أنه قيد الاستخدام من قبل برنامج آخر.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>لقطة</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>المسار</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>إخفاء النافذة</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>ثواني الانتظار قبل بدء التسجيل</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
