@@ -13,6 +13,41 @@
         <translation>Càmera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Elimina el marc de la finestra</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Gir vertical</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Gir horizontal</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertida</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Gris</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Blanc i negre</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Alterna a finestra</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Alterna a pantalla completa</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Alterna a pantalla completa</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Càmera</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>Ampliació</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Seleccioneu un o més dispositius</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
