@@ -13,6 +13,41 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Odstranit rám okna</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Překlopit svisle</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Překlopit vodorovně</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertovat</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Šedý</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Černá a bílá</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Přepnout do okna</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Přepnout na celou obrazovku</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Přepnout na celou obrazovku</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>Zvětšení</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Vyberte jedno nebo více zařízení</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
