@@ -13,6 +13,41 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Fensterrahmen entfernen</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Vertikal spiegeln</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Horizontal spiegeln</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertiert</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grau</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Schwarz-Weiß</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Auf Fenster umschalten</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Auf Vollbild umschalten</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Auf Vollbild umschalten</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>Lupe</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Ein oder mehrere Geräte auswählen</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -237,11 +283,11 @@
     </message>
     <message>
         <source>Invert</source>
-        <translation>invertiert</translation>
+        <translation>Invertiert</translation>
     </message>
     <message>
         <source>Gray</source>
-        <translation>grau</translation>
+        <translation>Grau</translation>
     </message>
     <message>
         <source>Black-and-white</source>
@@ -412,11 +458,11 @@
     </message>
     <message>
         <source>Invert</source>
-        <translation>invertiert</translation>
+        <translation>Invertiert</translation>
     </message>
     <message>
         <source>Gray</source>
-        <translation>grau</translation>
+        <translation>Grau</translation>
     </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
