@@ -14,7 +14,31 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraWindow</name>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Αφαίρεσε το πλαίσιο παραθύρου</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Κάθετη περιστροφή</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Οριζόντια περιστροφή</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Αντιστροφή</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Γκρι</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Ασπρόμαυρη</translation>
+    </message>
     <message>
         <source>Switch to Window</source>
         <translation>Εναλλαγή σε Παράθυρο</translation>
@@ -24,19 +48,34 @@
         <translation>Εναλλαγή σε Πλήρη οθόνη</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraWindow</name>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Εναλλαγή σε Παράθυρο</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Εναλλαγή σε Πλήρη οθόνη</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Κάμερα</translation>
+    </message>
+</context>
 <context>
     <name>QvkCiscoFinishDialog</name>
     <message>
         <source>The setup was successful.</source>
-        <translation type="unfinished"/>
+        <translation>Η εγκατάσταση ήταν επιτυχημένη</translation>
     </message>
     <message>
         <source>Close this window and start vokoscreenNG again.</source>
-        <translation type="unfinished"/>
+        <translation>Κλείστε αυτό το παράθυρο και ξεκινήστε το vokoscreenNG ξανά.</translation>
     </message>
     <message>
         <source>Have fun with vokoscreenNG</source>
-        <translation type="unfinished"/>
+        <translation>Διασκεδάστε με το vokoscreenNG</translation>
     </message>
 </context>
 <context>
@@ -84,7 +123,7 @@
     </message>
     <message>
         <source>Megabyte</source>
-        <translation>Μεγαμπάιτ</translation>
+        <translation>Megabyte</translation>
     </message>
     <message>
         <source>The recording was stopped, not enough free disk space.</source>
@@ -103,6 +142,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Δε βρέθηκε διαχειριστής αρχείων.</translation>
     </message>
     <message>
@@ -147,6 +187,17 @@
         <translation>Περιοχή</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Δε βρέθηκε διαχειριστής αρχείων.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Παρακαλώ εγκαταστήστε ένα διαχειριστή αρχείων.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -209,6 +260,13 @@
         <translation>Μεγένθυση</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Επιλογή μιας ή περισσότερων συσκευών</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -406,10 +464,6 @@
         <source>Gray</source>
         <translation>Γκρι</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Αποστολή Αναφοράς</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -440,7 +494,7 @@
     </message>
     <message>
         <source>Starts minimized</source>
-        <translation>Ανοίγει σε ελαχιστοποίηση</translation>
+        <translation>Εκκίνηση σε ελαχιστοποίηση</translation>
     </message>
     <message>
         <source>Flip horizontal</source>
@@ -488,39 +542,55 @@
     </message>
     <message>
         <source>Automatically</source>
-        <translation type="unfinished"/>
+        <translation>αυτόματα</translation>
     </message>
     <message>
         <source>Create images of tabs </source>
-        <translation type="unfinished"/>
+        <translation>Δημιουργία εικόνων των καρτελών</translation>
     </message>
     <message>
         <source>License information</source>
-        <translation type="unfinished"/>
+        <translation>Πληροφορίες για την άδεια χρήσης</translation>
     </message>
     <message>
         <source>ON</source>
-        <translation type="unfinished"/>
+        <translation>ΟΝ</translation>
     </message>
     <message>
         <source>OFF</source>
-        <translation type="unfinished"/>
+        <translation>ΟFF</translation>
     </message>
     <message>
         <source>Global keyboard shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>Συντομεύσεις πληκτρολογίου</translation>
     </message>
     <message>
         <source>Assigned shortcut keys.</source>
-        <translation type="unfinished"/>
+        <translation>Πλήκτρα με αντιστοίχιση</translation>
     </message>
     <message>
         <source>Keyboard shortcut not assigned or assigned more than once.</source>
-        <translation type="unfinished"/>
+        <translation>Δεν υπάρχει καμμία αντιστοίχηση πληκτρολογίου ή υπάρχουν περισσότερες από μία</translation>
     </message>
     <message>
         <source>If it shows assigned but does not work, it is being used by another program.</source>
-        <translation type="unfinished"/>
+        <translation>Αν έχει ένδειξη αντιστοίχισης αλλά δεν λειτουργεί, τότε χρησιμοποιείται από κάποιο άλλο πρόγραμμα.</translation>
+    </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Στιγμιότυπο</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Διαδρομή αποθήκευσης εικόνων</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Κρύψιμο αυτού του παραθύρου</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Δευτερόλεπτα αναμονής πριν την έναρξη της εγγραφής</translation>
     </message>
 </context>
 <context>
