@@ -13,6 +13,41 @@
         <translation>Cámara</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Quitar marco de ventana</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Voltear verticalmente</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Voltear horizontalmente</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertir</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Gris</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Blanco y negro</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Cambiar a ventana</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Ir a pantalla completa</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Ir a pantalla completa</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Cámara</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -72,7 +111,7 @@
     </message>
     <message>
         <source>The recording is not started, not enough free disk space.</source>
-        <translation>La grabación no empieza por insuficiencia de espacio en disco</translation>
+        <translation>No se pudo empezar a grabar, no hay suficiente espacio libre en el disco.</translation>
     </message>
     <message>
         <source>The free disk space limit is reached.</source>
@@ -222,6 +261,13 @@
         <translation>Ampliación</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Seleccione uno o más dispositivos</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -333,7 +379,7 @@
     </message>
     <message>
         <source>Stop recording after</source>
-        <translation>Dejar de grabar tras</translation>
+        <translation>Detener la grabación después de </translation>
     </message>
     <message>
         <source>Hours</source>
@@ -362,7 +408,7 @@
     </message>
     <message>
         <source>Second wait before recording</source>
-        <translation>Segunda espera antes de grabar</translation>
+        <translation>Segundos de espera antes de grabar</translation>
     </message>
     <message>
         <source>Look for updates</source>
@@ -422,15 +468,15 @@
     </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
-        <translation>Ctrl + Mayús + F10</translation>
+        <translation>CTRL+SHIFT+F10</translation>
     </message>
     <message>
         <source>CTRL+SHIFT+F11</source>
-        <translation>Ctrl + Mayús + F11</translation>
+        <translation>CTRL+SHIFT+F11</translation>
     </message>
     <message>
         <source>CTRL+SHIFT+F12</source>
-        <translation>Ctrl + Mayús + F12</translation>
+        <translation>CTRL+SHIFT+F12</translation>
     </message>
     <message>
         <source>Play last record</source>
@@ -486,7 +532,7 @@
     </message>
     <message>
         <source>Screencast</source>
-        <translation>Grabación de pantalla</translation>
+        <translation>Captura de pantalla</translation>
     </message>
     <message>
         <source>Player</source>
