@@ -3,7 +3,7 @@
     <name>QvkAudioController</name>
     <message>
         <source>Select one or more devices</source>
-        <translation>Elige uno o más dispositivos</translation>
+        <translation>Seleccione uno o más dispositivos</translation>
     </message>
 </context>
 <context>
@@ -14,29 +14,68 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraWindow</name>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Remover el marco de la ventana</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Distribuir en dos ventanas verticales</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Distribuir en dos ventanas horizontales</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertir</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Tonos de Gris</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Blanco y Negro</translation>
+    </message>
     <message>
         <source>Switch to Window</source>
-        <translation>Pasa a la Ventana</translation>
+        <translation>Cambiar a Ventana</translation>
     </message>
     <message>
         <source>Switch to Fullscreen</source>
-        <translation>Pasa a Pantalla Completa</translation>
+        <translation>Cambiar a pantalla completa</translation>
+    </message>
+</context>
+<context>
+    <name>QvkCameraWindow</name>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Cambiar a Ventana</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Cambiar a pantalla completa</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Cámara</translation>
     </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
     <message>
         <source>The setup was successful.</source>
-        <translation type="unfinished"/>
+        <translation>La instalación fue correcta.</translation>
     </message>
     <message>
         <source>Close this window and start vokoscreenNG again.</source>
-        <translation type="unfinished"/>
+        <translation>Cierra la ventana e inicia vokoscreenNG de nuevo.</translation>
     </message>
     <message>
         <source>Have fun with vokoscreenNG</source>
-        <translation type="unfinished"/>
+        <translation>Diviértete con vokoscreenNG</translation>
     </message>
 </context>
 <context>
@@ -103,6 +142,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>No se encontró el manejador de archivos.</translation>
     </message>
     <message>
@@ -147,6 +187,17 @@
         <translation>Área</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>No se encontró el manejador de archivos.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Por favor, instale un manejador de archivos.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -209,6 +260,13 @@
         <translation>Ampliación</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Seleccione uno o más dispositivos</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -406,10 +464,6 @@
         <source>Gray</source>
         <translation>Tonos de Gris</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Enviar el Reporte</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+MAYUS+F10</translation>
@@ -488,39 +542,55 @@
     </message>
     <message>
         <source>Automatically</source>
-        <translation type="unfinished"/>
+        <translation>Automáticamente</translation>
     </message>
     <message>
         <source>Create images of tabs </source>
-        <translation type="unfinished"/>
+        <translation>Crear imágenes de tabuladores</translation>
     </message>
     <message>
         <source>License information</source>
-        <translation type="unfinished"/>
+        <translation>Información de Licencia</translation>
     </message>
     <message>
         <source>ON</source>
-        <translation type="unfinished"/>
+        <translation>Inicio</translation>
     </message>
     <message>
         <source>OFF</source>
-        <translation type="unfinished"/>
+        <translation>Apagado</translation>
     </message>
     <message>
         <source>Global keyboard shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>Accesos directos globales de teclado</translation>
     </message>
     <message>
         <source>Assigned shortcut keys.</source>
-        <translation type="unfinished"/>
+        <translation>Teclas de acceso directo asignadas.</translation>
     </message>
     <message>
         <source>Keyboard shortcut not assigned or assigned more than once.</source>
-        <translation type="unfinished"/>
+        <translation>Acceso directo de teclado no asignado más de una vez.</translation>
     </message>
     <message>
         <source>If it shows assigned but does not work, it is being used by another program.</source>
-        <translation type="unfinished"/>
+        <translation>Si esto se muestra como asignado, pero no funciona, está siendo utilizado por otro programa.</translation>
+    </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Captura de pantalla</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Ruta de la imagen</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Oculta esta ventana</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Segundos de espera antes de grabar</translation>
     </message>
 </context>
 <context>
