@@ -13,6 +13,41 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Kendu leihoaren markoa</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Irauli bertikalean</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Irauli horizontalean</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Alderantzizkatu</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grisa</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Zuri-beltza</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Aldatu leihora</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Aldatu pantaila osora</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Aldatu pantaila osora</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>Lupa</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Hautatu gailu bat edo gehiago</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
