@@ -13,6 +13,41 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Poista ikkunakehys</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Käännä pystysuunnassa</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Käännä vaakasuunnassa</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Käänteinen</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Harmaa</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Mustavalkoinen</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Vaihda ikkunaan</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Vaihda koko näyttöön</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Vaihda koko näyttöön</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>Suurennus</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Valitse yksi tai useampi laite</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
