@@ -13,6 +13,41 @@
         <translation>Caméra</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Supprimer le cadre de la fenêtre </translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Retourner verticalement</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Retourner horizontalement</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Inverser</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Gris</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Noir-et-blanc</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Mode fenêtré</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Mode plein écran</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Mode plein écran</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Caméra</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>Agrandissement</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Sélectionnez un ou plusieurs appareils</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
