@@ -14,7 +14,31 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraWindow</name>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Hilangkan bingkai jendela</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Putar ke arah vertikal</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Putar ke arah horizontal</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Balikan</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Abu - abu</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Hitam-dan-putih</translation>
+    </message>
     <message>
         <source>Switch to Window</source>
         <translation>Pindah ke Jendela</translation>
@@ -24,6 +48,21 @@
         <translation>Pindah ke Layar Penuh</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraWindow</name>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Pindah ke Jendela</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Pindah ke Layar Penuh</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+</context>
 <context>
     <name>QvkCiscoFinishDialog</name>
     <message>
@@ -32,7 +71,7 @@
     </message>
     <message>
         <source>Close this window and start vokoscreenNG again.</source>
-        <translation>Tutup jendela dan mulai vokoscreenNG lagi.</translation>
+        <translation>Tutup jendela dan mulai ulang vokoscreenNG.</translation>
     </message>
     <message>
         <source>Have fun with vokoscreenNG</source>
@@ -57,11 +96,11 @@
     <name>QvkImageFromTabs</name>
     <message>
         <source>No filemanager found.</source>
-        <translation>Manajer berkas tidak ditemukan</translation>
+        <translation>Pengelola berkas tidak ditemukan.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
-        <translation>Mohon pasang manajer berkas</translation>
+        <translation>Mohon pasang pengelola berkas.</translation>
     </message>
 </context>
 <context>
@@ -103,6 +142,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Manajer erkas tidak ditemukan</translation>
     </message>
     <message>
@@ -130,7 +170,7 @@
     <name>QvkPulseAudioWatcher</name>
     <message>
         <source>Select one or more devices</source>
-        <translation>Pilih satu atau lebih perangkat</translation>
+        <translation>Pilih satu atau lebih perangkat.</translation>
     </message>
 </context>
 <context>
@@ -144,7 +184,18 @@
     <name>QvkRegionChoise_wl</name>
     <message>
         <source>Area</source>
-        <translation>Daerah</translation>
+        <translation>Bidangluas</translation>
+    </message>
+</context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Pengelola berkas tidak ditemukan.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Mohon pasang pengelola berkas.</translation>
     </message>
 </context>
 <context>
@@ -190,7 +241,7 @@
     </message>
     <message>
         <source>Pause</source>
-        <translation>Tangguhkan</translation>
+        <translation>Jeda</translation>
     </message>
     <message>
         <source>Continue</source>
@@ -209,6 +260,13 @@
         <translation>Pembesaran</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Pilih satu atau lebih perangkat.</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -406,10 +464,6 @@
         <source>Gray</source>
         <translation>Abu - abu</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Kirim Laporan</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -484,11 +538,11 @@
     </message>
     <message>
         <source>Log</source>
-        <translation>CtatanLog</translation>
+        <translation>Pencatatan</translation>
     </message>
     <message>
         <source>Automatically</source>
-        <translation>Otomatis</translation>
+        <translation>Secara otomatis</translation>
     </message>
     <message>
         <source>Create images of tabs </source>
@@ -500,15 +554,15 @@
     </message>
     <message>
         <source>ON</source>
-        <translation>ON</translation>
+        <translation>HIDUPKAN</translation>
     </message>
     <message>
         <source>OFF</source>
-        <translation>OFF</translation>
+        <translation>MATIKAN</translation>
     </message>
     <message>
         <source>Global keyboard shortcuts</source>
-        <translation>Tombol pintas global</translation>
+        <translation>Tombol-pintas umum</translation>
     </message>
     <message>
         <source>Assigned shortcut keys.</source>
@@ -522,6 +576,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Apabila telah diterapkan namun tidak bekerja, bisa jadi sedang digunakan oleh program lain.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Jepret-gambar</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Jalursimpan-gambar</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Sembunyikan jendela</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>detik waktu tunggu prarekam</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
