@@ -13,6 +13,41 @@
         <translation>Webcam</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Rimuovi bordo finestra</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Capovolgi verticale</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Capovolgi orizzontale</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Inverti</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grigio</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Bianco e nero</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Passa a Finestra</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Passa a Schermo Intero</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Passa a Schermo Intero</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Webcam</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>Ingrandisci</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Seleziona uno o più dispositivi</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
