@@ -13,6 +13,41 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Šalinti lango rėmelį</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Apversti vertikaliai</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Apversti horizontaliai</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertuoti</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Pilka</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Juoda ir balta</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Perjungti į langą</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Perjungti į visą ekraną</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Perjungti į visą ekraną</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>Didinimas</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Pasirinkite vieną ar daugiau įrenginių</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
