@@ -13,6 +13,41 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Fjern vindusramme</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Snu vertikalt</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Snu horisontalt</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertere</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grå</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Svart-hvit</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Bytt til vindu</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Bytt til fullskjerm</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Bytt til fullskjerm</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -103,6 +142,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Ingen filutforsker funnet.</translation>
     </message>
     <message>
@@ -147,6 +187,17 @@
         <translation>Område</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ingen filutforsker funnet.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Vennligst installere en filutforsker.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -209,6 +260,13 @@
         <translation>Forstørrelse</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Velg én til flere enheter</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -406,10 +464,6 @@
         <source>Gray</source>
         <translation>Grå</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Send Rapport</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -522,6 +576,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Hvis den vises som tildelt, men ikke virker, er den i bruk av et annet program.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Øyeblikksbilde</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Bildesti</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Skjul dette vinduet</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Sekunder venter før opptak</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
