@@ -13,6 +13,41 @@
         <translation>Camera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Vensterrand verwijderen</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Verticaal spiegelen</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Horizontaal spiegelen</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Omkeren</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grijs</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Zwart-wit</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Vensterweergave</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Schermvullende weergave</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Schermvullende weergave</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Camera</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>Vergroting</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Selecteer één of meer apparaten</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
