@@ -13,6 +13,41 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Usuń ramkę okna</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Odwróć pionowo</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Odwróć poziomo</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Odwróć</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Szary</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Czarno-białe</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Tryb okna</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Tryb pełnoekranowy</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Tryb pełnoekranowy</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>Powiększenie</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Wybierz jedno lub wiele urządzeń</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
