@@ -3,7 +3,7 @@
     <name>QvkAudioController</name>
     <message>
         <source>Select one or more devices</source>
-        <translation>Seleccione um ou mais dispositivos</translation>
+        <translation>Selecione um ou mais dispositivos</translation>
     </message>
 </context>
 <context>
@@ -13,6 +13,41 @@
         <translation>Camera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Remover a moldura da janela</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Girar vertical</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Girar horizontal</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Inverter</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Cinzento</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Preto e branco</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Mudar para janela</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Mudar para ecrã inteiro</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Mudar para ecrã inteiro</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Camera</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -61,7 +100,7 @@
     </message>
     <message>
         <source>Please install a filemanager.</source>
-        <translation>Por favor instale um gestor de ficheiros.</translation>
+        <translation>Por favor, instale um gestor de ficheiros.</translation>
     </message>
 </context>
 <context>
@@ -72,7 +111,7 @@
     </message>
     <message>
         <source>The recording is not started, not enough free disk space.</source>
-        <translation>A gravação não é iniciada, sem espaço em disco disponível.</translation>
+        <translation>A gravação não é iniciada, não há espaço livre em disco suficiente.</translation>
     </message>
     <message>
         <source>The free disk space limit is reached.</source>
@@ -103,11 +142,12 @@
     </message>
     <message>
         <source>No filemanager found.</source>
-        <translation>Não foi encontrado nenhum gestor de ficheiros.</translation>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
+        <translation>Nenhum gestor de ficheiros encontrado.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
-        <translation>Por favor instale um gestor de ficheiros.</translation>
+        <translation>Por favor, instale um gestor de ficheiros.</translation>
     </message>
     <message>
         <source>Sourcecode</source>
@@ -130,7 +170,7 @@
     <name>QvkPulseAudioWatcher</name>
     <message>
         <source>Select one or more devices</source>
-        <translation>Seleccione um ou mais dispositivos</translation>
+        <translation>Selecione um ou mais dispositivos</translation>
     </message>
 </context>
 <context>
@@ -147,6 +187,17 @@
         <translation>Área</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Não foi encontrado um gestor de ficheiros.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Por favor, instale um gestor de ficheiros.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -209,6 +260,13 @@
         <translation>Ampliação</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Selecione um ou mais dispositivos</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -406,10 +464,6 @@
         <source>Gray</source>
         <translation>Cinzento</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Enviar Relatório</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -522,6 +576,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Se mostrar atribuído, mas não funciona, ele está sendo usado por outro programa.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Instantâneo</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Caminho da imagem</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Esconder esta janela</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Espera em segundos antes de gravar</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
