@@ -13,6 +13,41 @@
         <translation>Câmera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Remover moldura da janela</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Girar na vertical</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Girar na horizontal</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Inverter</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Cinzento</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Preto e branco</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Mudar para Janela</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Alternar para Tela Cheia</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Alternar para Tela Cheia</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Câmera</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>Zoom</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Selecione um ou mais dispositivos</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
