@@ -13,6 +13,41 @@
         <translation>Камера</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Убрать рамку окна</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Отразить по вертикали</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Отразить по горизонтали</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Инвертировать</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Чёрно-белое в оттенках серого</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Чёрно-белое двухцветное</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Переключиться в режим окна</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Переключиться в полноэкранный режим</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Переключиться в полноэкранный режим</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Камера</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>Лупа</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Выберите одно или несколько устройств</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
