@@ -14,7 +14,31 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraWindow</name>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Odstrániť orámovanie okna</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Prevrátiť vertikálne</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Prevrátiť horizontálne</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertovať</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Stupne sivej</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Dvojfarebné, čierna a biela </translation>
+    </message>
     <message>
         <source>Switch to Window</source>
         <translation>Zobraziť v okne</translation>
@@ -24,19 +48,34 @@
         <translation>Zobraziť na celú obrazovku</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraWindow</name>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Zobraziť v okne</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Zobraziť na celú obrazovku</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+</context>
 <context>
     <name>QvkCiscoFinishDialog</name>
     <message>
         <source>The setup was successful.</source>
-        <translation type="unfinished"/>
+        <translation>Nastavenie bolo úspešné.</translation>
     </message>
     <message>
         <source>Close this window and start vokoscreenNG again.</source>
-        <translation type="unfinished"/>
+        <translation>Zatvorte okno a spustite vokoscreenNG opäť.</translation>
     </message>
     <message>
         <source>Have fun with vokoscreenNG</source>
-        <translation type="unfinished"/>
+        <translation>Zabávajte sa s vokoscreenNG</translation>
     </message>
 </context>
 <context>
@@ -103,6 +142,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Nenašiel sa žiadny súborový manažér.</translation>
     </message>
     <message>
@@ -147,6 +187,17 @@
         <translation>Oblasť</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Nenašiel sa žiadny súborový manažér.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Inštalujte súborový manažér.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -209,6 +260,13 @@
         <translation>Zväčšenie</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Vyberte jedno alebo viac zariadení</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -406,10 +464,6 @@
         <source>Gray</source>
         <translation>Stupne sivej</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Odoslať hlásenie</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -488,39 +542,55 @@
     </message>
     <message>
         <source>Automatically</source>
-        <translation type="unfinished"/>
+        <translation>Automaticky</translation>
     </message>
     <message>
         <source>Create images of tabs </source>
-        <translation type="unfinished"/>
+        <translation>Vytvoriť obrázky tabuliek</translation>
     </message>
     <message>
         <source>License information</source>
-        <translation type="unfinished"/>
+        <translation>Informácie o licencii</translation>
     </message>
     <message>
         <source>ON</source>
-        <translation type="unfinished"/>
+        <translation>ZAP.</translation>
     </message>
     <message>
         <source>OFF</source>
-        <translation type="unfinished"/>
+        <translation>VYP.</translation>
     </message>
     <message>
         <source>Global keyboard shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>Globálne klávesnicove skratky</translation>
     </message>
     <message>
         <source>Assigned shortcut keys.</source>
-        <translation type="unfinished"/>
+        <translation>Priradené kľúčové skratky</translation>
     </message>
     <message>
         <source>Keyboard shortcut not assigned or assigned more than once.</source>
-        <translation type="unfinished"/>
+        <translation>Klávesová skratka nie je priradená alebo je priradená viac ako raz</translation>
     </message>
     <message>
         <source>If it shows assigned but does not work, it is being used by another program.</source>
-        <translation type="unfinished"/>
+        <translation>Ak sa zobrazuje ako priradené, ale nefunguje, používa ho iný program.</translation>
+    </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Snímok obrazovky</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Cesta k obrázku</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Schovať okno</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Sekundy pred nahrávaním</translation>
     </message>
 </context>
 <context>
