@@ -14,7 +14,31 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraWindow</name>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Уклони оквир прозора</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Окрени вертикално</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Окрени хоризонтално</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Изокрени</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Сиво</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Црно-бело</translation>
+    </message>
     <message>
         <source>Switch to Window</source>
         <translation>Промени на прозор</translation>
@@ -24,19 +48,34 @@
         <translation>Промени на цео екран</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraWindow</name>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Промени на прозор</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Промени на цео екран</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+</context>
 <context>
     <name>QvkCiscoFinishDialog</name>
     <message>
         <source>The setup was successful.</source>
-        <translation type="unfinished"/>
+        <translation>Подешавање је успешно.</translation>
     </message>
     <message>
         <source>Close this window and start vokoscreenNG again.</source>
-        <translation type="unfinished"/>
+        <translation>Затвори овај прозор и покрени поново vokoscreenNG.</translation>
     </message>
     <message>
         <source>Have fun with vokoscreenNG</source>
-        <translation type="unfinished"/>
+        <translation>Забави се са vokoscreenNG</translation>
     </message>
 </context>
 <context>
@@ -103,6 +142,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Претраживач датотека није пронађен</translation>
     </message>
     <message>
@@ -147,6 +187,17 @@
         <translation>Подручје</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Претраживач датотека није пронађен</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Молим вас инсталирајте претраживач датотека</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -209,6 +260,13 @@
         <translation>Увеличавање</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Означи један или више уређаја</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -406,10 +464,6 @@
         <source>Gray</source>
         <translation>Сиво</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Пошаљи извештај</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -488,39 +542,55 @@
     </message>
     <message>
         <source>Automatically</source>
-        <translation type="unfinished"/>
+        <translation>Аутоматски</translation>
     </message>
     <message>
         <source>Create images of tabs </source>
-        <translation type="unfinished"/>
+        <translation>Креирај слике картица</translation>
     </message>
     <message>
         <source>License information</source>
-        <translation type="unfinished"/>
+        <translation>Информације о лиценци</translation>
     </message>
     <message>
         <source>ON</source>
-        <translation type="unfinished"/>
+        <translation>Укључи</translation>
     </message>
     <message>
         <source>OFF</source>
-        <translation type="unfinished"/>
+        <translation>Искључи</translation>
     </message>
     <message>
         <source>Global keyboard shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>Опште пречице на тастатури</translation>
     </message>
     <message>
         <source>Assigned shortcut keys.</source>
-        <translation type="unfinished"/>
+        <translation>Направљене пречице.</translation>
     </message>
     <message>
         <source>Keyboard shortcut not assigned or assigned more than once.</source>
-        <translation type="unfinished"/>
+        <translation>Пречица није додељена или је додељена више од једном.</translation>
     </message>
     <message>
         <source>If it shows assigned but does not work, it is being used by another program.</source>
-        <translation type="unfinished"/>
+        <translation>Ако се приказује додељено, али не ради, користи га други програм.</translation>
+    </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Снимак</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Путања слике</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Сакриј овај прозор</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Секунде пре почетка снимања</translation>
     </message>
 </context>
 <context>
