@@ -13,6 +13,41 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Ta bort fönsterram</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Vänd vertikalt</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Vänd horisontellt</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertera</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grå</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Svartvit</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Växla till fönsterläge</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Växla till helskärmsläge</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Växla till helskärmsläge</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>Förstoringsglas</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Välj en eller flera enheter</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
