@@ -13,6 +13,41 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Pencere çerçevesini kaldır</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Dikey çevir</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Yatay çevir</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Ters çevir</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Gri</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Siyah-ve-beyaz</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Pencereye Geç</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Tam Ekrana Geç</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Tam Ekrana Geç</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -116,7 +155,7 @@
     </message>
     <message>
         <source>Homepage</source>
-        <translation>Ana Sayfa</translation>
+        <translation>Web Sayfası</translation>
     </message>
     <message>
         <source>Translations</source>
@@ -221,6 +260,13 @@
         <translation>Büyüt</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Bir veya daha fazla aygıt seç</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -500,7 +546,7 @@
     </message>
     <message>
         <source>Create images of tabs </source>
-        <translation>Sekmelerde resim oluşturun</translation>
+        <translation>Sekmelerin ekran görüntülerini kaydet</translation>
     </message>
     <message>
         <source>License information</source>
