@@ -13,6 +13,41 @@
         <translation>Камера</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Прибрати рамку вікна</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Показати вертикально</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Показати горизонтально</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Перевернути</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Сірий</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>У відтінках сірого</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>Перемикнутися на режим вікна</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>Перемикнутися на повний екран</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>Перемикнутися на повний екран</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Камера</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -57,11 +96,11 @@
     <name>QvkImageFromTabs</name>
     <message>
         <source>No filemanager found.</source>
-        <translation>Файлового упорядника не знайдено.</translation>
+        <translation>Не знайдено файлового менеджера</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
-        <translation>Будь ласка встановіть файловий упорядник.</translation>
+        <translation>Будь ласка, встановіть файловий менеджер.</translation>
     </message>
 </context>
 <context>
@@ -103,6 +142,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Файлового упорядника не знайдено.</translation>
     </message>
     <message>
@@ -147,6 +187,17 @@
         <translation>Довільна область</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Файлового упорядника не знайдено.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Будь ласка встановіть файловий упорядник.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -209,6 +260,13 @@
         <translation>Збільшення</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Оберіть один або декілька пристроїв</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -406,10 +464,6 @@
         <source>Gray</source>
         <translation>Сірий</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Відправити скаргу</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -522,6 +576,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Якщо показує призначено, але не працює, то використовується іншою програмою.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Знімок</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Шлях до зображення</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Згорнути це вікно</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Зачекати секунду перед записуванням</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
