@@ -13,6 +13,41 @@
         <translation>摄像头</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>移除窗口边框</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>纵向翻转</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>横向翻转</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>翻转</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>灰度</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>黑白</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>切换至窗口模式</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>切换至全屏</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>切换至全屏</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>摄像头</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>放大</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>选取一个或多个设备</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
