@@ -13,6 +13,41 @@
         <translation>攝影機</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>移除視窗外框</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>垂直翻轉</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>水平翻轉</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>色彩反轉</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>灰色</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>黑白</translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation>切換至視窗</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>切換至全螢幕</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -23,6 +58,10 @@
         <source>Switch to Fullscreen</source>
         <translation>切換至全螢幕</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>攝影機</translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -221,6 +260,13 @@
         <translation>縮放</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>選取一個或多個裝置</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
