@@ -1,5 +1,5 @@
 /* vokoscreenNG - A desktop recorder
- * Copyright (C) 2017-2019 Volker Kohaupt
+ * Copyright (C) 2017-2022 Volker Kohaupt
  *
  * Author:
  *      Volker Kohaupt <vkohaupt@volkoh.de>
@@ -36,6 +36,7 @@
 #include <QLibraryInfo>
 #include <QLoggingCategory>
 #include <QStyleFactory>
+#include <QSettings>
 
 #include <gst/gst.h>
 
@@ -84,6 +85,10 @@ int main(int argc, char *argv[])
             return 0;
         }
 
+        if ( arguments.at(1) == "gst_appsrc" ) {
+            goto end;
+        }
+
         // If call from terminal and local file or remote file not exists
         QFile file( arguments.at(1) );
         if ( ( file.exists() == false ) and
@@ -95,15 +100,19 @@ int main(int argc, char *argv[])
             qDebug();
             return 1;
         }
+
     }
+    end:
 
     // Initialize GStreamer
     // https://developer.gnome.org/gstreamer/stable/gst-running.html
 #ifdef Q_OS_LINUX
-    QString separator = ":";
+    QString separator;
+    separator = ":";
 #endif
 #ifdef Q_OS_WIN
-    QString separator = ";";
+    QString separator;
+    separator = ";";
 #endif
 
     // qmake options example:
@@ -130,17 +139,31 @@ int main(int argc, char *argv[])
     pathRegistry.append( pathProfile );
     pathRegistry.append( "/gstreamer.registry" );
     qputenv( "GST_REGISTRY_1_0", pathRegistry.toUtf8() );
+#endif
 
-    /*
-        QString debugLevel = "4";
+    // Gstreamer debug begin
+    // Write Gstreamer debug level in a file
+    QvkSettings vkSettingsGstDebug;
+    QFileInfo fileInfo( vkSettingsGstDebug.getFileName() );
+    QString pathAndFilename = fileInfo.absoluteFilePath();
+    // qDebug() << "pathAndFilename:" << pathAndFilename;
+
+    QString pathToProfile = fileInfo.absolutePath();
+    // qDebug() << "pathProfile" << pathToProfile;
+
+    QSettings setingsGstDebug( pathAndFilename, QSettings::IniFormat );
+    QString debugLevel = setingsGstDebug.value( "sliderGstDebugLevel", "0" ).toString();
+    // qDebug() << "debugLevel:" << debugLevel;
+
+    if ( debugLevel.contains( "0" ) == false ) {
         qputenv( "GST_DEBUG", debugLevel.toUtf8() );
         QString debugPathProfile;
-        debugPathProfile.append( pathProfile );
+        debugPathProfile.append( pathToProfile );
         debugPathProfile.append( "/GST-Debuglevel-" + debugLevel + ".txt" );
         qputenv( "GST_DEBUG_FILE", debugPathProfile.toUtf8() );
-        */
+    }
+    // Gstreamer debug end
 
-#endif
 
     gst_init (&argc, &argv);
 
