@@ -1,8 +1,8 @@
 /* vokoscreenNG - A desktop recorder
- * Copyright (C) 2017-2019 Volker Kohaupt
+ * Copyright (C) 2017-2022 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -43,10 +43,12 @@ QvkPlayer::QvkPlayer( QMainWindow *parent, Ui_formMainWindow *ui_mainwindow ) :
     ui->horizontalLayout_2->setStretch( 0, 1 );
     sliderVideo->setObjectName( "sliderVideo" );
     sliderVideo->setTracking( true );
-    sliderVideo->setShowValue( false );
-    sliderVideo->setEnabled( false );
     sliderVideo->setMaximum(1);
     sliderVideo->show();
+    sliderVideo->setEnabled( false );
+    sliderVideo->setShowValue( false );
+    sliderVideo->setDecimalPoint( false );
+    sliderVideo->setBigHandel( false );
 
     sliderVolume = new QvkSpezialSlider( Qt::Horizontal );
     ui->horizontalLayout_3->insertWidget( 12, sliderVolume );
@@ -56,6 +58,10 @@ QvkPlayer::QvkPlayer( QMainWindow *parent, Ui_formMainWindow *ui_mainwindow ) :
     sliderVolume->setMinimum( 0 );
     sliderVolume->setMaximum( 100 );
     sliderVolume->show();
+    sliderVolume->setEnabled( true );
+    sliderVolume->setShowValue( true );
+    sliderVolume->setDecimalPoint( false );
+    sliderVolume->setBigHandel( true );
 
     parentMainWindow = parent;
     oldWindowTitel = parentMainWindow->windowTitle();
@@ -107,16 +113,22 @@ QvkPlayer::QvkPlayer( QMainWindow *parent, Ui_formMainWindow *ui_mainwindow ) :
         {
             case QMediaPlayer::NoError:
             {
-               qDebug() << global::nameOutput + " " + "[Player]" + " " + "No error has occurred.";
+               qDebug().noquote() << global::nameOutput + " " + "[Player]" + " " + "No error has occurred.";
                break;
             }
             case QMediaPlayer::ResourceError:
             {
-               qDebug() << global::nameOutput + " " + "[Player]" + " " + "To play this video a codec is needed. "
-                                                                         "Please install a codec pack.";
+               qDebug().noquote() << global::nameOutput + " " + "[Player]" + " " + "To play this video a codec is needed. "
+                                                                         "Please install a codec pack. "
+                                                                         "Note: For a recording, encoders are required, you can find them in a tab for "
+                                                                         "the recording. These cannot be used for the player. The player requires decoders.";
+
                QMessageBox msgBox( this );
-               msgBox.setText( "To play this video a codec is needed.\n"
-                               "Please install a codec pack." );
+               msgBox.setText( "To play this video a codec is needed. "
+                               "Please install a codec pack.\n"
+                               "\n"
+                               "Note: For a recording, encoders are required, you can find them in a tab for "
+                               "the recording. These cannot be used for the player. The player requires decoders.");
                msgBox.setWindowTitle( global::name + " " + global::version );
                msgBox.setIcon( QMessageBox::Information );
                msgBox.exec();
@@ -125,7 +137,7 @@ QvkPlayer::QvkPlayer( QMainWindow *parent, Ui_formMainWindow *ui_mainwindow ) :
             }
             case QMediaPlayer::FormatError:
             {
-               qDebug() << global::nameOutput + " " + "[Player]" + " " + "The format of a media resource isn't (fully) supported. Playback may still be possible, but without an audio or video component.";
+               qDebug().noquote() << global::nameOutput + " " + "[Player]" + " " + "The format of a media resource isn't (fully) supported. Playback may still be possible, but without an audio or video component.";
                QMessageBox msgBox( this );
                msgBox.setText( "The format of a media resource isn't (fully) supported.\n"
                                "Playback may still be possible, but without an audio or video component." );
@@ -136,7 +148,7 @@ QvkPlayer::QvkPlayer( QMainWindow *parent, Ui_formMainWindow *ui_mainwindow ) :
             }
             case QMediaPlayer::NetworkError:
             {
-               qDebug() << global::nameOutput + " " + "[Player]" + " " + "A network error occurred.";
+               qDebug().noquote() << global::nameOutput + " " + "[Player]" + " " + "A network error occurred.";
                QMessageBox msgBox( this );
                msgBox.setText( "A network error occurred." );
                msgBox.setWindowTitle( global::name + " " + global::version );
@@ -146,7 +158,7 @@ QvkPlayer::QvkPlayer( QMainWindow *parent, Ui_formMainWindow *ui_mainwindow ) :
             }
             case QMediaPlayer::AccessDeniedError:
             {
-               qDebug() << global::nameOutput + " " + "[Player]" + " " + "There are not the appropriate permissions to play a media resource.";
+               qDebug().noquote() << global::nameOutput + " " + "[Player]" + " " + "There are not the appropriate permissions to play a media resource.";
                QMessageBox msgBox( this );
                msgBox.setText( "There are not the appropriate permissions to play a media resource." );
                msgBox.setWindowTitle( global::name + " " + global::version );
@@ -156,7 +168,7 @@ QvkPlayer::QvkPlayer( QMainWindow *parent, Ui_formMainWindow *ui_mainwindow ) :
             }
             case QMediaPlayer::ServiceMissingError:
             {
-               qDebug() << global::nameOutput + " " + "[Player]" + " " + "A valid playback service was not found, playback cannot proceed.";
+               qDebug().noquote() << global::nameOutput + " " + "[Player]" + " " + "A valid playback service was not found, playback cannot proceed.";
                QMessageBox msgBox( this );
                msgBox.setText( "A valid playback service was not found, playback cannot proceed." );
                msgBox.setWindowTitle( global::name + " " + global::version );
@@ -166,7 +178,7 @@ QvkPlayer::QvkPlayer( QMainWindow *parent, Ui_formMainWindow *ui_mainwindow ) :
             }
             case QMediaPlayer::MediaIsPlaylist:
             {
-               qDebug() << global::nameOutput + " " + "[Player]" + " " + "QMediaPlayer::MediaIsPlaylist";
+               qDebug().noquote() << global::nameOutput + " " + "[Player]" + " " + "QMediaPlayer::MediaIsPlaylist";
                QMessageBox msgBox( this );
                msgBox.setText( "QMediaPlayer::MediaIsPlaylist" );
                msgBox.setWindowTitle( global::name + " " + global::version );
@@ -334,7 +346,12 @@ void QvkPlayer::slot_openFile()
 
     QString file;
     QvkFileDialog vkFileDialog( this );
-    vkFileDialog.setVideoPath( uiMainWindow->lineEditVideoPath->text() );
+    if ( !pathOpenFile.isEmpty() ) {
+        vkFileDialog.setVideoPath( pathOpenFile );
+    } else {
+        vkFileDialog.setVideoPath( uiMainWindow->lineEditVideoPath->text() );
+    }
+
     if ( vkFileDialog.exec() == QDialog::Accepted )
     {
         if ( !vkFileDialog.selectedFiles().empty() ) {
@@ -405,7 +422,9 @@ void QvkPlayer::slot_play()
 {
     show();
     mediaPlayer->play();
-    parentMainWindow->setWindowTitle( mediaPlayer->currentMedia().request().url().toString() + " - " + oldWindowTitel );
+    QUrl url( mediaPlayer->currentMedia().request().url() );
+    QString filename = url.fileName();
+    parentMainWindow->setWindowTitle( filename + " - " + oldWindowTitel );
 }
 
 
@@ -471,7 +490,7 @@ void QvkPlayer::slot_durationChanged( qint64 value )
 
 void QvkPlayer::slot_stateChanged( QMediaPlayer::State state )
 {
-    qDebug() << "[vokoplayer]" << state;
+    qDebug().noquote() << global::nameOutput + " " + "[Player]" << state;
 
     if ( state == QMediaPlayer::StoppedState )
     {
@@ -634,7 +653,6 @@ void QvkPlayer::vk_showFullscreen()
     ui->widgetMenueBar->setParent( ui->labelPlayer);
     ui->framePlayer->setStyleSheet( "QFrame { background-color: black; }"  );
     ui->widgetMenueBar->setStyleSheet( "QWidget { background-color: lightgray; }" );
-    ui->labelMovePicture->setStyleSheet( "QLabel { background-color: lightgray; }" );
     ui->toolButtonFullscreen->setIcon( QIcon( ":/pictures/player/restore.png" ) );
     ui->labelMovePicture->show();
     ui->widgetMenueBar->show();
