@@ -27,6 +27,7 @@
 #include <QFileInfo>
 #include <QMouseEvent>
 #include <QColor>
+#include <QDateTime>
 
 QvkSettings::QvkSettings()
 {
@@ -35,6 +36,16 @@ QvkSettings::QvkSettings()
     settings.beginGroup( global::name );
     settings.setValue( "Version", global::version );
     settings.endGroup();
+
+    QDateTime time;
+    time.setMSecsSinceEpoch( QDateTime::currentDateTime().currentMSecsSinceEpoch() );
+    QSettings installSetting( QSettings::IniFormat, QSettings::UserScope, global::name, QString( "InstallTime" ), Q_NULLPTR );
+    installSetting.beginGroup( global::name );
+    if ( installSetting.value( "version", "0.0.0" ).toString() != global::version ) {
+        installSetting.setValue( "time", time.toString( "yyyy.MM.dd-hh:mm:ss:zzz" ) );
+        installSetting.setValue( "version", global::version );
+    }
+    installSetting.endGroup();
 }
 
 QvkSettings::~QvkSettings(){}
@@ -174,7 +185,7 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
         }
 
         // We set WASAPI as default
-        if ( ( listRadiobuttons.at(i)->objectName() == "radioButtonDirectSound" ) and
+        if ( ( listRadiobuttons.at(i)->objectName() == "radioButtonWASAPI" ) and
              ( settings.value( listRadiobuttons.at(i)->objectName(), false ).toBool() == false ) )
         {
             listRadiobuttons.at(i)->click();
@@ -451,6 +462,25 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
         }
     }
 
+    QList<QToolButton *> listToolButtonCameraView = ui_mainwindow->centralWidget->findChildren<QToolButton *>( "toolButton_camera_view_" );
+    for ( int i = 0; i < listToolButtonCameraView.count(); i++ ) {
+        if ( listToolButtonCameraView.at(i)->objectName().contains( "toolButton_camera_view_Rectangle" ) ) {
+            if ( settings.value( listToolButtonCameraView.at(i)->objectName() ).toBool() == true ) {
+                listToolButton.at(i)->click();
+            }
+        }
+        if ( listToolButtonCameraView.at(i)->objectName().contains( "toolButton_camera_view_Ellipse" ) ) {
+            if ( settings.value( listToolButtonCameraView.at(i)->objectName() ).toBool() == true ) {
+                listToolButton.at(i)->click();
+            }
+        }
+        if ( listToolButtonCameraView.at(i)->objectName().contains( "toolButton_camera_view_Circlee" ) ) {
+            if ( settings.value( listToolButtonCameraView.at(i)->objectName() ).toBool() == true ) {
+                listToolButtonCameraView.at(i)->click();
+            }
+        }
+    }
+
     QList<QvkSpezialCheckbox *> listSpezialCheckbox = ui_mainwindow->centralWidget->findChildren<QvkSpezialCheckbox *>();
     for ( int i = 0; i < listSpezialCheckbox.count(); i++ )
     {
@@ -556,11 +586,11 @@ void QvkSettings::saveAll(Ui_formMainWindow *ui_mainwindow , QMainWindow *parent
         }
 
         if ( listToolButton.at(i)->objectName().contains( "toolButton_camera_view" ) ) {
-                settings.setValue( listToolButton.at(i)->objectName(), listToolButton.at(i)->isChecked() );
+            settings.setValue( listToolButton.at(i)->objectName(), listToolButton.at(i)->isChecked() );
         }
 
         if ( listToolButton.at(i)->objectName().contains( "toolButton_magnifier" ) ) {
-                settings.setValue( listToolButton.at(i)->objectName(), listToolButton.at(i)->isChecked() );
+            settings.setValue( listToolButton.at(i)->objectName(), listToolButton.at(i)->isChecked() );
         }
     }
 
@@ -618,7 +648,12 @@ void QvkSettings::readCamera( QvkCameraController *vkCameraController )
 {
     QSettings settings( QSettings::IniFormat, QSettings::UserScope, global::name, global::name, Q_NULLPTR );
     settings.beginGroup( "Camera" );
-    vkCameraController->cameraWindow->move( settings.value( "X", 0 ).toInt(), settings.value( "Y", 0 ).toInt() );
+#if (QT_VERSION <= QT_VERSION_CHECK(6, 0, 0))
+    // Qt5
+    vkCameraController->vkCameraWindow->move( settings.value( "X", 0 ).toInt(), settings.value( "Y", 0 ).toInt() );
+#else
+    // Qt6
+#endif
     settings.endGroup();
 }
 
@@ -639,6 +674,8 @@ void QvkSettings::readSystrayAlternative( QvkSystrayAlternative *vkSystrayAltern
     settings.endGroup();
 }
 
+#if (QT_VERSION <= QT_VERSION_CHECK(6, 0, 0))
+    // Qt5
 void QvkSettings::savePlayerPathOpenFile( QString pathFile )
 {
     QSettings settings( QSettings::IniFormat, QSettings::UserScope, global::name, global::name, Q_NULLPTR );
@@ -657,6 +694,9 @@ void QvkSettings::readPlayerPathOpenFile( QvkPlayer *vkplayer )
     vkplayer->pathOpenFile = settings.value( "Path", "" ).toString();
     settings.endGroup();
 }
+#else
+    // Qt6
+#endif
 
 void QvkSettings::saveHaloColor( QColor value )
 {
