@@ -15,6 +15,41 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Switch to Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraWindow</name>
     <message>
@@ -25,6 +60,10 @@
         <source>Switch to Fullscreen</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
@@ -223,6 +262,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
