@@ -1,5 +1,5 @@
 /* vokoscreenNG - A desktop recorder
- * Copyright (C) 2017-2019 Volker Kohaupt
+ * Copyright (C) 2017-2022 Volker Kohaupt
  * 
  * Author:
  *      Volker Kohaupt <vkohaupt@volkoh.de>
@@ -28,7 +28,7 @@
 #include <QWidget>
 
 #ifdef Q_OS_LINUX
-typedef QList<WId> WindowList;
+typedef QList<WId> listWinId;
 #endif
 
 #include "QvkGlobalMouse.h"
@@ -41,10 +41,10 @@ public:
     virtual ~QvkWinInfo();
     WId getWinID();
     static WId activeWindow();
-    QRectF windowGeometryWithoutFrame( WId child);
-
+    QRectF windowGeometryWithoutFrame( WId child );
     QvkGlobalMouse *vkGlobalMouse;
 
+
 public slots:
     void slot_start();
 
